summaryrefslogtreecommitdiff
path: root/lib/Target/Mips/MipsInstrInfo.h
diff options
context:
space:
mode:
authorAkira Hatanaka <ahatanak@gmail.com>2011-04-01 21:41:06 +0000
committerAkira Hatanaka <ahatanak@gmail.com>2011-04-01 21:41:06 +0000
commite2e436a6bc44deb2f989a39514f482b4932b93bc (patch)
tree69fc58a37b4c2c7adf8ee7507574b0d7072a1473 /lib/Target/Mips/MipsInstrInfo.h
parent6c1bead22b43edefb0c82f5509c8a681b58fdfa3 (diff)
downloadllvm-e2e436a6bc44deb2f989a39514f482b4932b93bc.tar.gz
llvm-e2e436a6bc44deb2f989a39514f482b4932b93bc.tar.bz2
llvm-e2e436a6bc44deb2f989a39514f482b4932b93bc.tar.xz
Simplifies logic for printing target flags.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@128741 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/Mips/MipsInstrInfo.h')
-rw-r--r--lib/Target/Mips/MipsInstrInfo.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/Target/Mips/MipsInstrInfo.h b/lib/Target/Mips/MipsInstrInfo.h
index 2f2e6734bb..5fdbf1f230 100644
--- a/lib/Target/Mips/MipsInstrInfo.h
+++ b/lib/Target/Mips/MipsInstrInfo.h
@@ -143,10 +143,10 @@ namespace MipsII {
/// for the relocatable object file being produced.
MO_GPREL,
/// MO_ABS_HILO - Represents the hi or low part of an absolute symbol
/// address.
- MO_ABS_HILO
-
+ MO_ABS_HI,
+ MO_ABS_LO
};
}
@@ -143,10 +143,10 @@ namespace MipsII {
/// for the relocatable object file being produced.
MO_GPREL,
- /// MO_ABS_HILO - Represents the hi or low part of an absolute symbol
+ /// MO_ABS_HI/LO - Represents the hi or low part of an absolute symbol
/// address.